.. datakit-project documentation master file

.. include:: ../README.rst

Links
=====

* Documentation: http://datakit-project.readthedocs.io/en/latest/
* Github: https://github.com/associatedpress/datakit-project
* PyPI: https://pypi.python.org/pypi/datakit-project
* Free and open source software: `ISC`_

.. _ISC: https://github.com/associatedpress/datakit-project/blob/master/LICENSE

Get Started
===========

.. toctree::
   install
   usage
   templates

==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

